import flagLookup from '../../../../domain/flagLookup';
import styles from './ScoreBoard.module.css';

const PlayerScoreTile = ({ name, guesses, totalScore, winner }) => (
  <div className={styles.tile}>
    <div className={styles.header}>
      <span className={styles.name}>{name}</span>
      <span className={styles.total}>{winner && '🏆'} {totalScore}</span>
    </div>
    <div className={styles.scores}>
      {Object.entries(guesses)
        .map(([ k, v ]) => [ parseInt(k), v ])
        .sort(([ k1 ], [ k2 ]) => (k1 < k2 ? -1 : k1 > k2 ? 1 : 0))
        .map(
          ([ num, { score, country } ]) =>
            score !== undefined ? (
              <div className={styles.round} key={num}>
                <span className={styles.score}>Round {num}: {score ?? 0}</span>
                <span className={styles.flag}>{ flagLookup(country) }</span>
              </div>
            ) : null
        )}
    </div>
  </div>
);

const ScoreBoard = ({ players }) => (
  <div className={styles.scoreboard}>
    {players
      .filter(({ currentRound }) => currentRound === null)
      .sort((p1, p2) => (p1.totalScore > p2.totalScore ? -1 : p1.totalScore < p2.totalScore ? 1 : 0))
      .map((data, i) => <PlayerScoreTile key={data.name} winner={i === 0} {...data} />)}
  </div>
);

export default ScoreBoard;
